/**
 * Copyright 2010 Xeus Technologies 
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 */

package org.xeustechnologies.esl4j.impl;

import java.util.Map;

import org.apache.log4j.Level;
import org.xeustechnologies.esl4j.LogFactory;
import org.xeustechnologies.esl4j.Logger;

/**
 * A LogFactory for Apache's log4j logging framework
 * 
 * @author Kamran
 * 
 */
public class Log4jLogFactory implements LogFactory {

    public Logger getLogger(Class clazz) {
        return new Log4jLogger( org.apache.log4j.Logger.getLogger( clazz ) );
    }

    public void setProperties(Map<String, String> props) {
    }

    public static final class Log4jLogger implements Logger {

        private org.apache.log4j.Logger logger;

        public Log4jLogger(org.apache.log4j.Logger logger) {
            this.logger = logger;
        }

        public void debug(String message) {
            if( isDebugEnabled() ) {
                logger.debug( message );
            }
        }

        public void debug(String message, Throwable error) {
            if( isDebugEnabled() ) {
                logger.debug( message, error );
            }
        }

        public void debug(Throwable error) {
            if( isDebugEnabled() ) {
                logger.debug( "", error );
            }
        }

        public void error(String message) {
            if( isErrorEnabled() ) {
                logger.error( message );
            }
        }

        public void error(String message, Throwable error) {
            if( isErrorEnabled() ) {
                logger.error( message, error );
            }
        }

        public void error(Throwable error) {
            if( isErrorEnabled() ) {
                logger.error( "", error );
            }
        }

        public void info(String message) {
            if( isInfoEnabled() ) {
                logger.info( message );
            }
        }

        public void info(String message, Throwable error) {
            if( isInfoEnabled() ) {
                logger.info( message, error );
            }
        }

        public void info(Throwable error) {
            if( isInfoEnabled() ) {
                logger.info( "", error );
            }
        }

        public boolean isDebugEnabled() {
            return logger.isDebugEnabled();
        }

        public boolean isErrorEnabled() {
            return logger.isEnabledFor( Level.ERROR );
        }

        public boolean isInfoEnabled() {
            return logger.isInfoEnabled();
        }

        public boolean isTraceEnabled() {
            return logger.isTraceEnabled();
        }

        public boolean isVerboseEnabled() {
            return logger.isInfoEnabled();
        }

        public boolean isWarnEnabled() {
            return logger.isEnabledFor( Level.WARN );
        }

        public void trace(String message) {
            if( isTraceEnabled() ) {
                logger.trace( message );
            }
        }

        public void trace(String message, Throwable error) {
            if( isTraceEnabled() ) {
                logger.trace( message, error );
            }
        }

        public void trace(Throwable error) {
            if( isTraceEnabled() ) {
                logger.trace( "", error );
            }
        }

        public void verbose(String message) {
            if( isVerboseEnabled() ) {
                logger.info( message );
            }
        }

        public void verbose(String message, Throwable error) {
            if( isVerboseEnabled() ) {
                logger.info( message, error );
            }
        }

        public void verbose(Throwable error) {
            if( isVerboseEnabled() ) {
                logger.info( "", error );
            }
        }

        public void warn(String message) {
            if( isWarnEnabled() ) {
                logger.warn( message );
            }
        }

        public void warn(String message, Throwable error) {
            if( isWarnEnabled() ) {
                logger.warn( message, error );
            }
        }

        public void warn(Throwable error) {
            if( isWarnEnabled() ) {
                logger.warn( error );
            }
        }

    }
}
